"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.FTPProgressHandler = void 0;
const imperative_1 = require("@zowe/imperative");
const PERCETAGE = 100;
class FTPProgressHandler {
    constructor(progress, estimated = false) {
        this.progress = progress;
        this.estimated = estimated;
    }
    start(total) {
        this.total = total;
        this.processed = 0;
        if (this.estimated) {
            this.statusMessage = "Downloaded %d of %d (Estimated) bytes";
        }
        else {
            this.statusMessage = "Downloaded %d of %d bytes";
        }
        this.task = {
            statusMessage: "Starting transfer...",
            percentComplete: 0,
            stageName: imperative_1.TaskStage.IN_PROGRESS
        };
        this.progress.startBar({ task: this.task });
    }
    worked(work) {
        this.processed += work;
        this.task.percentComplete = PERCETAGE * this.processed / this.total;
        this.task.statusMessage = imperative_1.TextUtils.formatMessage(this.statusMessage, this.processed, this.total);
    }
    end() {
        this.progress.endBar();
    }
}
exports.FTPProgressHandler = FTPProgressHandler;
//# sourceMappingURL=FTPProgressHandler.js.map