/// <reference types="node" />
/// <reference types="node" />
import { ICommandProfileTypeConfiguration, Logger } from "@zowe/imperative";
import * as stream from "stream";
/**
 * The data is transferred in text mode, in which encoding conversion like ASCII/EBCDIC will happen.
 */
export declare const TRANSFER_TYPE_ASCII = "ascii";
/**
 * The data is transferred in binary mode, in which no encoding conversion will happen.
 */
export declare const TRANSFER_TYPE_BINARY = "binary";
/**
 * The data is transferred in text mode like TRANSFER_TYPE_ASCII, and 4-byte RDW is inserted at beginning of each record.
 */
export declare const TRANSFER_TYPE_ASCII_RDW = "ascii_rdw";
/**
  * The data is transferred in binary mode like TRANSFER_TYPE_BINARY, and 4-byte RDW is inserted at beginning of each record.
  */
export declare const TRANSFER_TYPE_BINARY_RDW = "binary_rdw";
export declare class CoreUtils {
    /**
     * Sleep for a number of milliseconds
     * @param ms - how many miliseconds to sleep or (at least)
     * @returns promise that resolves when the sleep is complete (or after, not guaranteed)
     */
    static sleep(ms: number): Promise<unknown>;
    /**
     * Make sure newlines in a string have carriage returns
     * This is required to prevent errors when transferring
     * in ascii mode
     * @param  original - the original string which you would like to ensure has \r before \n
     * @returns a string where every \n has a \r before it
     */
    static addCarriageReturns(original: string): string;
    /**
     * Read the complete contents of stdin
     * @param stream - A custom stream to read stdin data from
     * @returns contents piped in to stdin
     */
    static readStdin(stream?: stream.Readable): Promise<Buffer>;
    static addLowerCaseKeysToObject(obj: any): any;
    static getProfileMeta(): Promise<ICommandProfileTypeConfiguration[]>;
    protected static get log(): Logger;
}
