"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
const FTPConfig_1 = require("./api/FTPConfig");
const config = {
    commandModuleGlobs: ["**/cli/*/*.definition!(.d).*s"],
    rootCommandDescription: "Data set and job functionality via FTP. This functionality " +
        "uses the open source zos-node-accessor package from IBM. Commands under this group " +
        "require you to create a zftp profile before using them.\n" +
        "If you find this functionality useful, please consider setting up z/OSMF on " +
        "your system to get improved stability and speed and more features (for example, issuing TSO and console commands) by using " +
        "core Zowe CLI.",
    productDisplayName: "z/OS FTP Plugin",
    pluginAliases: ["zftp"],
    pluginSummary: "z/OS Files and jobs via FTP",
    pluginHealthCheck: "./lib/healthCheck.handler",
    name: "zos-ftp",
    profiles: [
        {
            type: "zftp",
            createProfileExamples: [{
                    options: "myprofile -u ibmuser -p ibmp4ss -H sys123",
                    description: "Create a zftp profile called 'myprofile' with default settings (port" +
                        ", timeout, etc.) to connect with the host system 123."
                }],
            schema: {
                type: "object",
                title: "Configuration profile for z/OS FTP",
                description: "Configuration profile for z/OS FTP",
                properties: {
                    host: {
                        type: "string",
                        optionDefinition: FTPConfig_1.FTPConfig.OPTION_HOST
                    },
                    port: {
                        type: "number",
                        optionDefinition: FTPConfig_1.FTPConfig.OPTION_PORT,
                        includeInTemplate: true
                    },
                    user: {
                        type: "string",
                        optionDefinition: FTPConfig_1.FTPConfig.OPTION_USER,
                        secure: true
                    },
                    password: {
                        type: "string",
                        optionDefinition: FTPConfig_1.FTPConfig.OPTION_PASSWORD,
                        secure: true
                    },
                    secureFtp: {
                        type: ["boolean", "null"],
                        optionDefinition: FTPConfig_1.FTPConfig.OPTION_SECURE_FTP,
                        includeInTemplate: true
                    },
                    rejectUnauthorized: {
                        type: ["boolean", "null"],
                        optionDefinition: FTPConfig_1.FTPConfig.OPTION_REJECT_UNAUTHORIZED
                    },
                    servername: {
                        type: ["string", "null"],
                        optionDefinition: FTPConfig_1.FTPConfig.OPTION_SERVER_NAME
                    },
                    connectionTimeout: {
                        type: "number",
                        optionDefinition: FTPConfig_1.FTPConfig.OPTION_CONNECTION_TIMEOUT
                    },
                    encoding: {
                        type: "string",
                        optionDefinition: FTPConfig_1.FTPConfig.OPTION_ENCODING
                    },
                },
                optional: ["host", "port", "user", "password", "encoding"],
            },
        },
    ]
};
module.exports = config;
//# sourceMappingURL=imperative.js.map